# -*- coding:utf-8 -*-
from evilunit import test_target
import unittest


@test_target("prestring:PreString")
class PreStringTests(unittest.TestCase):
    def test0(self):
        target = self._makeOne("foo")
        self.assertEqual(str(target), "foo")

    def test1(self):
        target = self._makeOne("foo")
        result = target + "boo"
        self.assertEqual(str(result), "fooboo")

    def test2(self):
        target = self._makeOne("foo")
        result = target + self._makeOne("boo")
        self.assertEqual(str(result), "fooboo")

    def test3(self):
        target = self._makeOne("foo")
        target += "boo"
        self.assertEqual(str(target), "fooboo")

    def test4(self):
        target = self._makeOne("foo")
        target += self._makeOne("boo")
        self.assertEqual(str(target), "fooboo")

    def test5(self):
        target = self._makeOne("foo")
        result = target + self._makeOne("boo")
        result = result + result
        self.assertEqual(str(result), "fooboofooboo")



# -*- coding:utf-8 -*-
import unittest
from evilunit import test_target


@test_target("prestring.python:PythonModule")
class Tests(unittest.TestCase):
    def test_from_statement(self):
        m = self._makeOne(indent="@")
        m.from_("foo", "a", "b")
        m.from_("boo", "x")
        m.from_("foo", "c")
        result = str(m).split("\n")
        expected = ["from foo import(", "@a,", "@b,", "@c", ")", "from boo import x"]
        self.assertEqual(result, expected)

    def test_short_call(self):
        m = self._makeOne(indent="@", width=100)
        m.call("f", "x", "y", "z='foo'")
        result = str(m)
        self.assertEqual(result, "f(x, y, z='foo')")

    def test_long_long_call(self):
        m = self._makeOne(indent="@", width=100)
        m.call("SomeLongNameClass", "x", "y", "long long argument 0", "long long argument 1", "long long argument 2", "long long argument 3")
        expected = [
            "SomeLongNameClass(", '@x,', '@y,',
            "@long long argument 0,",
            "@long long argument 1,",
            "@long long argument 2,",
            "@long long argument 3)"
        ]
        result = str(m).split("\n")
        self.assertEqual(result, expected)



# -*- coding:utf-8 -*-

import os
import sys


from setuptools import setup, find_packages
here = os.path.abspath(os.path.dirname(__file__))
try:
    with open(os.path.join(here, 'README.rst')) as f:
        README = f.read()
    with open(os.path.join(here, 'CHANGES.txt')) as f:
        CHANGES = f.read()
except IOError:
    README = CHANGES = ''


install_requires = [
]


docs_extras = [
]

tests_require = [
]

testing_extras = tests_require + [
]

setup(name='prestring',
      version='0.2.5',
      description='source code generation library (with overuse with-syntax)',
      long_description=README + '\n\n' + CHANGES,
      classifiers=[
          "Programming Language :: Python",
          "Programming Language :: Python :: Implementation :: CPython",
      ],
      keywords='',
      author="podhmo",
      author_email="",
      url="https://github.com/podhmo/prestring",
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      install_requires=install_requires,
      extras_require={
          'testing': testing_extras,
          'docs': docs_extras,
      },
      tests_require=tests_require,
      test_suite="prestring.tests",
      entry_points="""
""")




# -*- coding:utf-8 -*-
from evilunit import test_target
import unittest


@test_target("prestring:Evaluator")
class EvalatorTests(unittest.TestCase):
    def _makeOne(self, indent=" "):
        from io import StringIO
        return self._getTarget()(StringIO(), indent=indent)

    def test_flatten_string(self):
        target = self._makeOne()
        script = ["foo", "bar", "boo"]
        target.evaluate(script)

        result = str(target)
        self.assertEqual(result, "foo\nbar\nboo")

    def test_flatten_prestring(self):
        from prestring import PreString

        target = self._makeOne()
        script = [PreString("foo"), PreString("bar"), PreString("boo")]
        target.evaluate(script)

        result = str(target)
        self.assertEqual(result, "foo\nbar\nboo")

    def test_indented_string(self):
        target = self._makeOne(indent="@")
        script = ["foo", ["bar", "boo"], "yey"]
        target.evaluate(script)
        result = str(target).split("\n")
        self.assertEqual(result, ["foo", "@bar", "@boo", "yey"])

    def test_indented_string2(self):
        target = self._makeOne(indent="@")
        script = ["foo", ["bar", ["boo"], "bar"], "yey", [["beh"]]]
        target.evaluate(script)
        result = str(target).split("\n")
        self.assertEqual(result, ["foo", "@bar", "@@boo", "@bar", "yey", "@@beh"])

    def test_indented_string3(self):
        target = self._makeOne(indent="@")
        script = [[["foo", "bar"]]]
        target.evaluate(script)
        result = str(target).split("\n")
        self.assertEqual(result, ["@@foo", "@@bar"])

